# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.image_settings import ImageSettings  # noqa: E501

class TestImageSettings(unittest.TestCase):
    """ImageSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageSettings:
        """Test ImageSettings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImageSettings`
        """
        model = ImageSettings()  # noqa: E501
        if include_optional:
            return ImageSettings(
                model = 'dall-e-2',
                count = 56,
                size = 'auto',
                quality = 'low',
                output_format = 'png'
            )
        else:
            return ImageSettings(
                model = 'dall-e-2',
                count = 56,
                size = 'auto',
                quality = 'low',
                output_format = 'png',
        )
        """

    def testImageSettings(self):
        """Test ImageSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr, validator

class ImageSettings(BaseModel):
    """
    ImageSettings
    """
    model: StrictStr = Field(...)
    count: StrictInt = Field(...)
    size: StrictStr = Field(...)
    quality: StrictStr = Field(...)
    output_format: StrictStr = Field(...)
    __properties = ["model", "count", "size", "quality", "output_format"]

    @validator('model')
    def model_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('dall-e-2', 'dall-e-3', 'gpt-image-1', 'gpt-image-1-mini',):
            raise ValueError("must be one of enum values ('dall-e-2', 'dall-e-3', 'gpt-image-1', 'gpt-image-1-mini')")
        return value

    @validator('size')
    def size_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('auto', '1024x1024', '1536x1024', '1024x1536',):
            raise ValueError("must be one of enum values ('auto', '1024x1024', '1536x1024', '1024x1536')")
        return value

    @validator('quality')
    def quality_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('low', 'medium', 'high', 'auto', 'standard',):
            raise ValueError("must be one of enum values ('low', 'medium', 'high', 'auto', 'standard')")
        return value

    @validator('output_format')
    def output_format_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('png', 'jpeg', 'webp',):
            raise ValueError("must be one of enum values ('png', 'jpeg', 'webp')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ImageSettings:
        """Create an instance of ImageSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ImageSettings:
        """Create an instance of ImageSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ImageSettings.parse_obj(obj)

        _obj = ImageSettings.parse_obj({
            "model": obj.get("model"),
            "count": obj.get("count"),
            "size": obj.get("size"),
            "quality": obj.get("quality"),
            "output_format": obj.get("output_format")
        })
        return _obj





# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openai_connector.api.openai_api import OpenaiApi  # noqa: E501


class TestOpenaiApi(unittest.IsolatedAsyncioTestCase):
    """OpenaiApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OpenaiApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_embeddings_v1_openai_embeddings_create_post(self) -> None:
        """Test case for create_embeddings_v1_openai_embeddings_create_post

        Create embeddings  # noqa: E501
        """
        pass

    async def test_generate_image_v1_openai_image_generate_post(self) -> None:
        """Test case for generate_image_v1_openai_image_generate_post

        Generate image  # noqa: E501
        """
        pass

    async def test_generate_response_v1_openai_response_generate_post(self) -> None:
        """Test case for generate_response_v1_openai_response_generate_post

        Generate response  # noqa: E501
        """
        pass

    async def test_stream_response_v1_openai_response_stream_post(self) -> None:
        """Test case for stream_response_v1_openai_response_stream_post

        Stream response  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.chat_role import ChatRole  # noqa: E501

class TestChatRole(unittest.TestCase):
    """ChatRole unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testChatRole(self):
        """Test ChatRole"""
        # inst = ChatRole()

if __name__ == '__main__':
    unittest.main()
